@@ -17,8 +17,11 @@ from .main import (corpus,
                    corpus_insert_book,
                    book_write,
                    book_read,
+                   metadata,
                    doc_id,
                    logger,
 )
 
+from .search import (creator_name,
+                     title)
 from .epub import read
