@@ -6,7 +6,7 @@ import tempfile
 import logging
 from  datetime import datetime
 
-from typing import List, Union, Optional, Dict
+from typing import List, Union, Optional, Dict, Any
 from pathlib import Path
 from tinydb import TinyDB, database, table, queries, Query
 
@@ -48,15 +48,6 @@ logger.addHandler(logger_console)
 logger.addHandler(logger_fd)
 
 
-def book_dir(path: Union[str, Path]) -> Path:
-    """ Return a bookdir path, given a datapath. Often datapath is
-    read from CORPUS_DATAPATH environment variable"""
-    # Resolve the zip file path.  zip dirname is: repository-branch
-    datadir: str = 'litcorpt_data-main/data/'
-    booksdir: Path = Path(path) / datadir
-    return booksdir
-
-
 def book_json_path(path: Union[str, Path]) -> Path:
     """Return a book's json path, from a dirpath
 
@@ -358,7 +349,7 @@ def corpus_load(rebuild: bool = False) -> database.TinyDB:
         # Corpus database do not exist (or rebuild). Lets build it.
 
         # Read corpus from book's dir
-        booksdir: Path = book_dir(corpus_datapath)
+        booksdir: Path = utils.book_dir(corpus_datapath)
         books: List[model.Book] = corpus_read(booksdir)
 
         # Build corpus
@@ -380,7 +371,7 @@ def corpus_insert_book(corpusdb: database.TinyDB, book: model.Book) -> List[int]
     document_id: List[int] = corpusdb.upsert(book_document, Query().index == book.index)
 
     # Write book to bookdir
-    booksdir: Path = book_dir(utils.get_corpus_datapath())
+    booksdir: Path = utils.book_dir(utils.get_corpus_datapath())
     book_write(book, booksdir / book.index)
 
     return document_id
@@ -408,6 +399,40 @@ def corpus(corpusdb: database.TinyDB,
     return local_corpus
 
 
+def metadata(corpusdb: database.TinyDB,
+             query: Optional[queries.QueryInstance] = None) -> List[model.Book]:
+    """Return a list of Book models given corpusdb and a query (optional).
+    If no query is given, return all documents.
+
+    Input:
+        corpusdb (db): A corpus database handler
+        query (query): A query request. If no query is given, return all documents.
+
+    Output:
+        List[model.Book]: A list of book metadata (without contents)
+    """
+    result: List[table.Document]
+    if query is None:
+        result = corpusdb.all()
+    else:
+        result = corpusdb.search(query)
+
+    model_args: Dict[str, Any] = {'exclude': {'contents'},
+                                  'exclude_defaults': True,
+                                  'exclude_none': True,
+                                  'exclude_unset': True}
+
+    book: model.Book
+    books: List[model.Book] = []
+    for entry in result:
+        book = model.Book(**entry)
+        book_dict = book.dict(**model_args)
+        book = model.Book(**book_dict)
+        books.append(book)
+
+    return books
+
+
 def doc_id(corpusdb: database.TinyDB,
            query: Optional[queries.QueryInstance] = None) -> List[int]:
     """Return a list of document ids given a query
