@@ -5,6 +5,7 @@ import re
 import logging
 
 from itertools import cycle
+from typing import Union, Generator, List
 
 from urllib.parse import urlparse
 
@@ -15,10 +16,26 @@ import requests
 
 logger: logging.Logger = logging.getLogger(__name__)
 
-def spinning_wheel():
+def spinning_wheel() -> Generator[None, None, None]:
     """Print a frame of a spinning wheel"""
-    for frame in cycle(r'-\|/'):
-        print(f'\b{frame}', sep='', end='', flush=True)
+    #whell: str=r"-\|/"
+    #whell: str=r"⣾⣽⣻⢿⡿⣟⣯⣷"
+    #whell: str=r"🕛🕐🕑🕒🕓🕔🕕🕖🕗🕘🕙🕚"
+    # whell: List[str]= ["▹▹▹▹▹",
+    #                    "▸▹▹▹▹",
+    #                    "▹▸▹▹▹",
+    #                    "▹▹▸▹▹",
+    #                    "▹▹▹▸▹",
+    #                    "▹▹▹▹▸"]
+    whell: List[str] = ["⢀⠀", "⡀⠀", "⠄⠀", "⢂⠀", "⡂⠀", "⠅⠀", "⢃⠀", "⡃⠀", "⠍⠀",
+                        "⢋⠀", "⡋⠀", "⠍⠁", "⢋⠁", "⡋⠁", "⠍⠉", "⠋⠉", "⠋⠉", "⠉⠙",
+                        "⠉⠙", "⠉⠩", "⠈⢙", "⠈⡙", "⢈⠩", "⡀⢙", "⠄⡙", "⢂⠩", "⡂⢘",
+                        "⠅⡘", "⢃⠨", "⡃⢐", "⠍⡐", "⢋⠠", "⡋⢀", "⠍⡁", "⢋⠁", "⡋⠁",
+                        "⠍⠉", "⠋⠉", "⠋⠉", "⠉⠙", "⠉⠙", "⠉⠩", "⠈⢙", "⠈⡙", "⠈⠩",
+                        "⠀⢙", "⠀⡙", "⠀⠩", "⠀⢘", "⠀⡘", "⠀⠨", "⠀⢐", "⠀⡐", "⠀⠠",
+                        "⠀⢀", "⠀⡀"]
+    for frame in cycle(whell):
+        print(f'{frame}\r', sep='', end='', flush=True)
         yield
 
 
@@ -44,12 +61,12 @@ def download_file(url: str, dstdir: str = '.', filename: str = None):
         if filename is None:
             # Name from http headers
             if 'content-disposition' in req.headers:
-                disposition = req.headers['content-disposition']
+                disposition: str = req.headers['content-disposition']
                 filename = re.findall("filepath=(.+)", disposition)[0]
 
             # We got a redirect
             if req.history:
-                hist_req = req.history[0]
+                hist_req: requests.models.Response = req.history[0]
                 if hist_req.status_code == 302:
                     url = hist_req.headers.get('Location', url)
 
@@ -58,7 +75,7 @@ def download_file(url: str, dstdir: str = '.', filename: str = None):
                 filename = urlparse(url).path.split('/')[-1]
 
         # Check filesize (only works when stream=False)
-        expected_filesize = 0
+        expected_filesize: int = 0
         if 'Content-Length' in req.headers:
             expected_filesize = int(req.headers['Content-Length'])
 
@@ -99,3 +116,12 @@ def get_corpus_url() -> str:
     corpus_url = os.getenv('CORPUS_URL', corpus_url_default)
 
     return corpus_url
+
+
+def book_dir(path: Union[str, Path]) -> Path:
+    """ Return a bookdir path, given a datapath. Often datapath is
+    read from CORPUS_DATAPATH environment variable"""
+    # Resolve the zip file path.  zip dirname is: repository-branch
+    datadir: str = 'litcorpt_data-main/data/'
+    booksdir: Path = Path(path) / datadir
+    return booksdir
